@@ -1296,7 +1296,7 @@ GdkPixbuf *
 fileio_extract_icon (const gchar *file,
                      const guint  icon_size)
 {
-#ifdef G_OS_WIN32
+#if defined (G_OS_WIN32)
   GdkPixbuf *pixbuf = NULL;
   HICON hIcon = NULL;
   ICONINFO ii;
@@ -1419,7 +1419,125 @@ fileio_extract_icon (const gchar *file,
       DeleteObject (ii.hbmMask);
     }
   return pixbuf;
-#else /* not G_OS_WIN32 */
+#elif GLIB_CHECK_VERSION(2,4,0) && defined (MIMEFILE)
+  GdkPixbuf *pixbuf = NULL;
+
+  if (!file)
+    return NULL;
+  if (!g_file_test (file, G_FILE_TEST_IS_DIR))
+    {
+      gchar *text;
+      gssize length;
+
+      text = fileio_load (MIMEFILE, &length);
+      if (text)
+        {
+          gchar **mimes, *utf8str, *mime_type = NULL;
+          gint i;
+
+          text = g_realloc (text, length + 1);
+          text[length] = '\0';
+          utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
+          mimes = g_strsplit (text, "\n", 0);
+          for (i = 0; mimes[i]; i++)
+            {
+              gchar **globs;
+
+              globs = g_strsplit (mimes[i], G_SEARCHPATH_SEPARATOR_S, 0);
+              if (globs[0])
+                {
+                  gint j;
+
+                  for (j = 1; globs[j]; j++)
+                    if (g_pattern_match_simple (globs[j], utf8str))
+                      {
+                        mime_type = g_strdup (globs[0]);
+                        break;
+                      }
+                }
+              g_strfreev (globs);
+              if (mime_type)
+                break;
+            }
+          g_strfreev (mimes);
+          g_free (utf8str);
+          g_free (text);
+          if (mime_type)
+            {
+              gchar *icon_name, *separator;
+
+              icon_name = g_strconcat ("gnome-mime-", mime_type, NULL);
+              g_free (mime_type);
+              separator = g_strchr (icon_name, '/');
+              if (separator)
+                {
+                  GtkIconTheme *icon_theme;
+
+                  *separator = '-';
+                  icon_theme = gtk_icon_theme_get_default ();
+                  if (icon_theme)
+                    {
+                      gboolean result;
+
+                      result = gtk_icon_theme_has_icon (icon_theme, icon_name);
+                      if (!result)
+                        {
+                          *separator = '\0';
+                          result = gtk_icon_theme_has_icon (icon_theme,
+                                                                    icon_name);
+                        }
+                      if (result)
+# if GLIB_CHECK_VERSION(2,6,0)
+                        {
+                          gint *sizes;
+
+                          sizes = gtk_icon_theme_get_icon_sizes (icon_theme,
+                                                                    icon_name);
+                          if (sizes)
+                            {
+                              gint n = 0, s;
+
+                              s = icon_size == FILEIO_ICON_SIZE_SMALL
+                                                                    ? 16 : 32;
+                              for (i = 0; sizes[i] > 0; i++)
+                                if (ABS (s - sizes[i]) < ABS (s - n))
+                                  n = sizes[i];
+                              g_free (sizes);
+                              if (n > 0)
+                                pixbuf = gtk_icon_theme_load_icon (icon_theme,
+                                                        icon_name, n, 0, NULL);
+                            }
+                        }
+# else /* not GLIB_CHECK_VERSION(2,6,0) */
+                        pixbuf = gtk_icon_theme_load_icon (icon_theme,
+                            icon_name,
+                            icon_size == FILEIO_ICON_SIZE_SMALL ? 16 : 32,
+                            0, NULL);
+# endif /* not GLIB_CHECK_VERSION(2,6,0) */
+                    }
+                }
+              g_free (icon_name);
+            }
+        }
+    }
+# if 0
+  if (!pixbuf)
+    {
+      GtkWidget *image;
+
+      image = gtk_image_new ();
+      pixbuf = gtk_widget_render_icon (image,
+                                    g_file_test (file, G_FILE_TEST_IS_DIR)
+                                        ? GTK_STOCK_DIRECTORY : GTK_STOCK_FILE,
+                                    icon_size == FILEIO_ICON_SIZE_SMALL
+                                        ? GTK_ICON_SIZE_SMALL_TOOLBAR
+                                        : GTK_ICON_SIZE_LARGE_TOOLBAR,
+                                    NULL);
+      gtk_widget_destroy (image);
+    }
+# endif
+  return pixbuf;
+#else /* not G_OS_WIN32 && not MIMEFILE */
   return NULL;
-#endif /* not G_OS_WIN32 */
+#endif /* not G_OS_WIN32 && not MIMEFILE */
 }
