@@ -122,7 +122,10 @@ command_open (GtkWidget *widget,
       ofn.lStructSize = sizeof (OPENFILENAMEW);
       ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
       ofn.lpstrFilter = lpszFilter;
-      ofn.nFilterIndex = findex - 1;
+      for (i = ftnum - 1; i >= 0; i--)
+        if (ftype[i].ft_id == findex)
+          break;
+      ofn.nFilterIndex = i + 1;
       ofn.lpstrCustomFilter = NULL;
       ofn.lpstrFile = szFile;
       ofn.nMaxFile = MAX_PATH;
@@ -189,7 +192,10 @@ command_open (GtkWidget *widget,
       ofn.lStructSize = sizeof (OPENFILENAMEA);
       ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
       ofn.lpstrFilter = lpszFilter;
-      ofn.nFilterIndex = findex - 1;
+      for (i = ftnum - 1; i >= 0; i--)
+        if (ftype[i].ft_id == findex)
+          break;
+      ofn.nFilterIndex = i + 1;
       ofn.lpstrCustomFilter = NULL;
       ofn.lpstrFile = szFile;
       ofn.nMaxFile = MAX_PATH;
@@ -244,7 +250,7 @@ command_open (GtkWidget *widget,
         gtk_file_filter_add_pattern (filter, ext[j]);
       g_strfreev (ext);
       gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
-      if (i == findex)
+      if (ftype[i].ft_id == findex)
         gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
       g_object_set_data (G_OBJECT (filter), "user_data", GINT_TO_POINTER (i));
     }
@@ -302,7 +308,7 @@ command_save (GtkWidget *widget,
       const gchar *file;
 
       file = orz_mdi_get_file (ORZ_MDI (mdi), page_num);
-      if (tmaid->ft.overwrite && fileio_isfile (file))
+      if (tmaid->ft.overwrite && g_file_test (file, G_FILE_TEST_EXISTS))
         {
           gchar *utf8str;
           GtkWidget *dialog;
@@ -556,7 +562,7 @@ command_saveas (GtkWidget *widget,
 
       page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
       tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
-      if (tmaid->ft.overwrite && fileio_isfile (file))
+      if (tmaid->ft.overwrite && g_file_test (file, G_FILE_TEST_EXISTS))
         {
           gchar *filename;
 #ifdef G_OS_WIN32
