@@ -34,6 +34,8 @@ static void
 ftype_copy (FileType *ft_dst,
             FileType *ft_src)
 {
+  gboolean success[12];
+
   ft_dst->ft_id = ft_src->ft_id;
   ft_dst->crlf = ft_src->crlf;
   ft_dst->margin = ft_src->margin;
@@ -64,6 +66,8 @@ ftype_copy (FileType *ft_dst,
   g_free (ft_dst->ext);
   ft_dst->ext = ft_src->ext ? g_strdup (ft_src->ext) : NULL;
   g_memmove (ft_dst->color, ft_src->color, sizeof (GdkColor) * 12);
+  gdk_colormap_alloc_colors (gdk_colormap_get_system (),
+                                    ft_dst->color, 12, FALSE, TRUE, success);
 }
 
 
