@@ -493,7 +493,7 @@ modify_margin (TmaidWindow *tmaid)
     while (p)
       {
         data_pos = screen_pos = 0;
-        while (data_pos<p->length)
+        while (data_pos < p->length)
           if (p->text[data_pos] == '\t')
             {
               screen_pos = (screen_pos / tmaid->ft.tab + 1) * tmaid->ft.tab;
@@ -521,7 +521,7 @@ modify_margin (TmaidWindow *tmaid)
           {
             /* ja:右マージンを超えているとき、擬似改行する */
             q = g_malloc (sizeof (LineBuffer));
-            q->length = p->length-data_pos;
+            q->length = p->length - data_pos;
             q->margin = p->margin;
             q->text = g_malloc (q->length * sizeof (gchar));
             q->prev = p;
@@ -613,9 +613,15 @@ prompt_close (TmaidWindow *tmaid)
                             _("File %s was edited.\nSave?"), utf8str);
       g_free (utf8str);
       gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+#ifdef G_OS_WIN32
+                                        GTK_STOCK_YES, GTK_RESPONSE_YES,
+                                        GTK_STOCK_NO, GTK_RESPONSE_NO,
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#else /* not G_OS_WIN32 */
                                         GTK_STOCK_NO, GTK_RESPONSE_NO,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                         GTK_STOCK_YES, GTK_RESPONSE_YES,
+#endif /* not G_OS_WIN32 */
                                         NULL);
       g_signal_connect (G_OBJECT (dialog), "key-press-event",
                                     G_CALLBACK (misc_dialog_key_press), NULL);
