@@ -362,14 +362,10 @@ signal_expose_preedit (GtkWidget      *widget,
   pango_attr_list_unref (attrs);
 
   gc = gdk_gc_new (widget->window);
-  gdk_color_alloc (gdk_colormap_get_system (),
-                    (tmaid->ft.syscol ? system_color : tmaid->ft.color));
-  gdk_color_alloc (gdk_colormap_get_system (),
-                    (tmaid->ft.syscol ? system_color : tmaid->ft.color) + 1);
   /* ja:背景 */
   gdk_gc_set_foreground (gc, (tmaid->ft.syscol
                                         ? system_color : tmaid->ft.color) + 1);
-  gdk_draw_rectangle(widget->window, gc, TRUE, event->area.x, event->area.y,
+  gdk_draw_rectangle (widget->window, gc, TRUE, event->area.x, event->area.y,
                                         event->area.width, event->area.height);
   /* ja:文字 */
   gdk_gc_set_foreground (gc, (tmaid->ft.syscol
@@ -403,12 +399,9 @@ signal_expose (GtkWidget      *widget,
   gc = gdk_gc_new (widget->window);
   gdk_gc_set_line_attributes (gc, 1,
                                 GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
-  for (i = 0; i < 10; i++)
-    gdk_color_alloc (gdk_colormap_get_system (),
-                    (tmaid->ft.syscol ? system_color : tmaid->ft.color) + i);
-    cursor.x = edit_get_align_pos (tmaid,
+  cursor.x = edit_get_align_pos (tmaid,
                                    tmaid->cursor.x, tmaid->cursor.y, FALSE);
-    cursor.y = tmaid->cursor.y;
+  cursor.y = tmaid->cursor.y;
   if (tmaid->select.x == -1)
     {
       /* ja:選択範囲がないとき */
