@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,14 +16,13 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "charset.h"
 #include "edit.h"
 #include "general.h"
 #include "sigfile.h"
 #include "sigkey.h"
-#include "misc/misc.h"
 #include "orz/orzmdi.h"
+#include <gdk/gdkkeysyms.h>
 
 
 /******************************************************************************
@@ -140,7 +139,7 @@ signal_key_press (GtkWidget   *widget,
               case GDK_comma:
               case GDK_less:
                 if (!ctrl)
-                  break;
+                  return result;
                 tmaid->cursor.x = edit_get_align_pos (tmaid,
                                     tmaid->cursor.x, tmaid->cursor.y, FALSE);
                 if (tmaid->cursor.x > 0)
@@ -158,7 +157,7 @@ signal_key_press (GtkWidget   *widget,
               case GDK_period:
               case GDK_greater:
                 if (!ctrl)
-                  break;
+                  return result;
                 width = edit_get_width (tmaid, tmaid->cursor.y);
                 if (tmaid->cursor.x < width)
                   {
@@ -293,7 +292,7 @@ signal_key_press (GtkWidget   *widget,
           else if (tmaid->select.x >= 0)
             clear_sel (tmaid, &tmaid->cursor, &cursor);
         }
-        result=TRUE;
+        result = TRUE;
         break;
       case GDK_BackSpace:
         {
@@ -333,7 +332,7 @@ signal_key_press (GtkWidget   *widget,
           orz_mdi_set_edited (ORZ_MDI (mdi),
                     orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
         }
-        result=TRUE;
+        result = TRUE;
         break;
       case GDK_Return:
       case GDK_KP_Enter:
@@ -429,7 +428,7 @@ signal_key_press (GtkWidget   *widget,
                             orz_mdi_get_data (ORZ_MDI (mdi), page))->drawing);
             }
         }
-        result=TRUE;
+        result = TRUE;
         break;
       case GDK_Escape:
       case GDK_Cancel:
@@ -465,7 +464,7 @@ signal_key_press (GtkWidget   *widget,
           clear_sel (tmaid, &select, &tmaid->cursor);
           draw_caret (tmaid, NULL);
         }
-        result=TRUE;
+        result = TRUE;
         break;
       case GDK_Delete:
       case GDK_KP_Delete:
