@@ -38,10 +38,11 @@ signal_style_set (GtkWidget *widget,
                   GtkStyle  *style,
                   gpointer   user_data)
 {
+  gboolean success[9];
   gint i;
 
-  /* ja:システム色 */
   style = gtk_widget_get_style (widget);
+  /* ja:システム色 */
   system_color[0] = style->text[0];
   system_color[1] = style->base[0];
   system_color[2] = style->dark[0];
@@ -52,9 +53,11 @@ signal_style_set (GtkWidget *widget,
   system_color[7] = style->mid[0];
   system_color[8] = style->fg[3];
   system_color[9] = style->bg[3];
+  gdk_colormap_alloc_colors (gdk_colormap_get_system (),
+                                        system_color, 9, FALSE, TRUE, success);
+  /* ja:システムフォント */
   if (system_font)
     pango_font_description_free (system_font);
-  /* ja:システムフォント */
   system_font = pango_font_description_copy
                                     (pango_context_get_font_description
                                     (gtk_widget_get_pango_context (widget)));
